emacs-orgmode
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: [Orgmode] org-plot and timestamps


From: Charles Sebold
Subject: Re: [Orgmode] org-plot and timestamps
Date: Mon, 27 Oct 2008 15:51:48 -0500
User-agent: Gnus/5.11 (Gnus v5.11) Emacs/22.3 (windows-nt)

On 27 Oct 2008, Charles Sebold wrote:

> How's this for a first pass?  Not a git user before I started with
> org-mode so any pointers on how to generate these would be
> appreciated.

How embarrassing.  This is the patch I meant to send:

Changes in origin/HEAD
        Modified lisp/org-plot.el
diff --git a/lisp/org-plot.el b/lisp/org-plot.el
index db67257..d0d62f6 100644
--- a/lisp/org-plot.el
+++ b/lisp/org-plot.el
@@ -101,10 +101,16 @@ will be added.  Returns the resulting property list."
        (org-plot/add-options-to-plist params (match-string 1 line))
       params)))
 
+(defun org-plot-quote-timestamp-field (s)
+  "Convert field S from timestamp to Unix time and export to gnuplot."
+  (format-time-string "%Y-%m-%d-%H:%M:%S" (org-time-string-to-time s)))
+
 (defun org-plot-quote-tsv-field (s)
   "Quote field S for export to gnuplot."
   (if (string-match org-table-number-regexp s) s
-    (concat "\"" (mapconcat 'identity (split-string s "\"") "\"\"") "\"")))
+    (if (string-match org-ts-regexp3 s)
+        (org-plot-quote-timestamp-field s)
+      (concat "\"" (mapconcat 'identity (split-string s "\"") "\"\"") "\""))))
 
 (defun org-plot/gnuplot-to-data (table data-file params)
   "Export TABLE to DATA-FILE in a format readable by gnuplot.
@@ -180,6 +186,7 @@ NUM-COLS controls the number of columns plotted in a 2-d 
plot."
         (title (plist-get params :title))
         (file (plist-get params :file))
         (ind (plist-get params :ind))
+         (time-ind (plist-get params :timeind))
         (text-ind (plist-get params :textind))
         (deps (if (plist-member params :deps) (plist-get params :deps)))
         (col-labels (plist-get params :labels))
@@ -217,6 +224,9 @@ NUM-COLS controls the number of columns plotted in a 2-d 
plot."
                 (mapconcat (lambda (pair)
                              (format "\"%s\" %d" (cdr pair) (car pair)))
                            y-labels ", "))))
+      (when time-ind ;; timestamp index
+        (add-to-script "set xdata time")
+        (add-to-script "set timefmt \"%Y-%m-%d-%H:%M:%S\""))
       (case type ;; plot command
        ('2d (dotimes (col num-cols)
               (unless (and (equal type '2d)
@@ -284,16 +294,24 @@ line directly before or after the table."
        ('grid (let ((y-labels (org-plot/gnuplot-to-grid-data
                                table data-file params)))
                 (when y-labels (plist-put params :ylabels y-labels)))))
       ;; check for text ind column
       (let ((ind (- (plist-get params :ind) 1)))
-       (when (and (>= ind 0) (equal '2d (plist-get params :plot-type)))
-         (if (> (length
-                 (delq 0 (mapcar
+        (when (and (>= ind 0) (equal '2d (plist-get params :plot-type)))
+          (if (= (length
+                  (delq 0 (mapcar
                           (lambda (el)
-                            (if (string-match org-table-number-regexp el)
+                            (if (string-match org-ts-regexp3 el)
                                 0 1))
                           (mapcar (lambda (row) (nth ind row)) table)))) 0)
-             (plist-put params :textind t))))
+             (plist-put params :timeind t)
+            ;; check for text ind column
+            (if (> (length
+                    (delq 0 (mapcar
+                             (lambda (el)
+                               (if (string-match org-table-number-regexp el)
+                                   0 1))
+                             (mapcar (lambda (row) (nth ind row)) table)))) 0)
+                (plist-put params :textind t)))))
       ;; write script
       (with-temp-buffer
        (if (plist-get params :script) ;; user script
@@ -307,7 +325,8 @@ line directly before or after the table."
        (gnuplot-mode)
        (gnuplot-send-buffer-to-gnuplot))
       ;; cleanup
-      (bury-buffer (get-buffer "*gnuplot*"))(delete-file data-file))))
+      (bury-buffer (get-buffer "*gnuplot*"))
+      (delete-file data-file))))
 
 (provide 'org-plot)
 
@@ -284,16 +294,24 @@ line directly before or after the table."
                                table data-file params)))
                 (when y-labels (plist-put params :ylabels y-labels)))))
-      ;; check for text ind column
+      ;; check for timestamp ind column
       (let ((ind (- (plist-get params :ind) 1)))


-- 
Charles Sebold
http://merbc.invigorated.org/
http://triablogue.blogspot.com/




reply via email to

[Prev in Thread] Current Thread [Next in Thread]